{% extends 'cccontact/base.html' %}

{% block title %}Thanks{% endblock %}

{% block content %}
<h1> Thanks </h1>
<p>
	Thanks for getting in touch with us &ndash; we'll get back to you
	as soon as we can.
</p>
{% endblock %}
